from django import template
from django.utils.text import slugify
from unidecode import unidecode

register = template.Library()


@register.filter(name="unislugify")
def unislugify(value):
    """Convert to ASCII"""
    return slugify(unidecode(value))


@register.filter(name="exif_exposuretime")
def exif_exposuretime(value):
    """Convert ExposureTime"""
    try:
        return f"1/{int(1/float(value))} sec"
    except:
        return ""


@register.filter(name="exif_fnumber")
def exif_fnumber(value):
    """Convert FNumber"""
    try:
        return f"ƒ/{float(value)}"
    except:
        return ""


@register.filter(name="exif_focallength")
def exif_focallength(value):
    """Convert Focal Length"""
    try:
        return f"{int(value)} mm"
    except:
        return ""


@register.filter(name="exif_isospeedratings")
def exif_isospeedratings(value):
    """Convert ISO Speed Ratings"""
    try:
        return f"{int(value)}"
    except:
        return ""
    

@register.filter(name="exif_keywords")
def exif_keywords(value):
    """Convert Keywords"""
    try:
        words = list(dict.fromkeys(value))
        return ", ".join(words)
    except:
        return ""