from math import floor

from django import template
from django.core.cache import cache
from django.templatetags.static import static

register = template.Library()


@register.filter
def photo_image_data(photo):
    """
    Generate resized image data for Photo objects.
    """
    if not photo:
        return {
            "url": static("img/placeholder.png"),
            "width": 1200,
            "height": 800,
            "aspect_ratio": round(1200 / 800, 3),
            "is_placeholder": True,
        }

    cache_key = f'photo_md_image_data_{photo.pk}'
    data = cache.get(cache_key)

    if data:
        return data

    max_w, max_h = 720, 720

    if not photo.width or not photo.height:
        data = {
            "url": static("img/placeholder.png"),
            "width": 1200,
            "height": 800,
            "aspect_ratio": round(1200 / 800, 3),
            "is_placeholder": True,
        }
    else:
        aspect = photo.aspect_ratio
        if photo.width > photo.height:
            w = min(photo.width, max_w)
            h = floor(w / aspect)
        else:
            h = min(photo.height, max_h)
            w = floor(h * aspect)

        data = {
            "url": photo.photo_md.url,
            "width": w,
            "height": h,
            "aspect_ratio": round(aspect, 3),
            "is_placeholder": False,
        }

    cache.set(cache_key, data, 60 * 60 * 24)
    return data
